==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_StoryTopic.pm <==
package WebGUI::i18n::German::Asset_StoryTopic;
use utf8;
our $I18N = {
  'Read more stories' => {
    'lastUpdated' => '1253865024',
    'message' => 'Weitere Berichte lesen'
  },
  'assetName' => {
    'lastUpdated' => '1252335893',
    'message' => 'Berichtsthema'
  },
  'atomUrl' => {
    'lastUpdated' => '1252335912',
    'message' => 'URL zum Atom-Feed für dieses Berichtsthema'
  },
  'creationDate' => {
    'lastUpdated' => '1252336430',
    'message' => 'Datum als Epochangabe, an dem der Bericht erstellt oder ins Berichtarchiv augenommen wurde.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1252336026',
    'message' => 'Icon um den Bericht zu löschen. Hat der Nutzer keine Löschberechtigung oder ist sein UI-Level zu gering, dann ist diese Variable leer.'
  },
  'editIcon' => {
    'lastUpdated' => '1252336053',
    'message' => 'Icon um den Bericht zu bearbeiten. Hat der Nutzer keine Bearbeiten-Berechtigung oder ist sein UI-Level zu gering, dann ist diese Variable leer.'
  },
  'rssUrl' => {
    'lastUpdated' => '1252336071',
    'message' => 'URL zum RSS-Feed für dieses Berichtsthema'
  },
  'standAlone' => {
    'lastUpdated' => '1252336176',
    'message' => 'Diese Variable ist wahr, wenn das Berichtsthema direkt durch seinen URL betrachtet wird. Wenn es innerhalb eines Seitenlayouts oder anderen Containers betrachtet wird ist die Variable falsch.'
  },
  'stories per topic' => {
    'lastUpdated' => '1252336185',
    'message' => 'Berichte pro Thema'
  },
  'stories per topic help' => {
    'lastUpdated' => '1252336239',
    'message' => 'Anzahl der Berichte zu diesem Berichtsthema im RSS- oder Atom-Feed und wenn das Thema direkt angezeigt wird.'
  },
  'stories short' => {
    'lastUpdated' => '1252336249',
    'message' => 'Berichte pro Steite'
  },
  'stories short help' => {
    'lastUpdated' => '1252336265',
    'message' => 'Anzahl der angezeigten Berichte pro Seite'
  },
  'story template' => {
    'lastUpdated' => '1252336274',
    'message' => 'Berichtstemplate'
  },
  'story template help' => {
    'lastUpdated' => '1252336318',
    'message' => 'Template zur Anzeige von Berichtsassets zu diesem Berichtsthema'
  },
  'story_loop' => {
    'lastUpdated' => '1252336349',
    'message' => 'Eine Schleife die die letzten Berichte zu diesem Thema enthält'
  },
  'storytopic asset template variables title' => {
    'lastUpdated' => '1252336355',
    'message' => 'Story Topic Asset Template Variables'
  },
  'template' => {
    'lastUpdated' => '1252336365',
    'message' => 'Haupttemplate'
  },
  'template help' => {
    'lastUpdated' => '1252336416',
    'message' => 'Template zur Anzeige des Berichtsthemas'
  },
  'title' => {
    'lastUpdated' => '1252336394',
    'message' => 'Titel des Berichts'
  },
  'topStoryCreationDate' => {
    'lastUpdated' => '1252336445',
    'message' => 'Datum als Epochangabe, an dem der Bericht erstellt oder ins Berichtarchiv augenommen wurde.'
  },
  'topStoryImageAlt' => {
    'lastUpdated' => '1252336520',
    'message' => 'Alternativer Bildtext des ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageByline' => {
    'lastUpdated' => '1252336532',
    'message' => 'Unterschrift des des ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageCaption' => {
    'lastUpdated' => '1252336547',
    'message' => 'Bildüberschrift des ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageLink' => {
    'lastUpdated' => '1252336563',
    'message' => 'Link zum ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageTitle' => {
    'lastUpdated' => '1252336578',
    'message' => 'Bildtitel des ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageUrl' => {
    'lastUpdated' => '1252336590',
    'message' => 'URL zum ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStorySubtitle' => {
    'lastUpdated' => '1252336603',
    'message' => 'Untertitel des Top-Berichtes'
  },
  'topStoryTitle' => {
    'lastUpdated' => '1252336612',
    'message' => 'Titel des Topberichtes'
  },
  'topStoryUrl' => {
    'lastUpdated' => '1252336631',
    'message' => 'URL um den Topbericht anzuzeigen'
  },
  'url' => {
    'lastUpdated' => '1252336647',
    'message' => 'URL um einen Bericht anzuzeigen'
  },
  'view template' => {
    'lastUpdated' => '1252336654',
    'message' => 'View Story Topic Template'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_StoryTopic.pm <==
package WebGUI::i18n::German::Asset_StoryTopic;
use utf8;
our $I18N = {
  'Read more stories' => {
    'lastUpdated' => '1253865024',
    'message' => 'Weitere Berichte lesen'
  },
  'assetName' => {
    'lastUpdated' => '1252335893',
    'message' => 'Berichtsthema'
  },
  'atomUrl' => {
    'lastUpdated' => '1252335912',
    'message' => 'URL zum Atom-Feed für dieses Berichtsthema'
  },
  'creationDate' => {
    'lastUpdated' => '1252336430',
    'message' => 'Datum als Epochangabe, an dem der Bericht erstellt oder ins Berichtarchiv augenommen wurde.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1252336026',
    'message' => 'Icon um den Bericht zu löschen. Hat der Nutzer keine Löschberechtigung oder ist sein UI-Level zu gering, dann ist diese Variable leer.'
  },
  'editIcon' => {
    'lastUpdated' => '1252336053',
    'message' => 'Icon um den Bericht zu bearbeiten. Hat der Nutzer keine Bearbeiten-Berechtigung oder ist sein UI-Level zu gering, dann ist diese Variable leer.'
  },
  'rssUrl' => {
    'lastUpdated' => '1252336071',
    'message' => 'URL zum RSS-Feed für dieses Berichtsthema'
  },
  'standAlone' => {
    'lastUpdated' => '1252336176',
    'message' => 'Diese Variable ist wahr, wenn das Berichtsthema direkt durch seinen URL betrachtet wird. Wenn es innerhalb eines Seitenlayouts oder anderen Containers betrachtet wird ist die Variable falsch.'
  },
  'stories per topic' => {
    'lastUpdated' => '1252336185',
    'message' => 'Berichte pro Thema'
  },
  'stories per topic help' => {
    'lastUpdated' => '1252336239',
    'message' => 'Anzahl der Berichte zu diesem Berichtsthema im RSS- oder Atom-Feed und wenn das Thema direkt angezeigt wird.'
  },
  'stories short' => {
    'lastUpdated' => '1252336249',
    'message' => 'Berichte pro Steite'
  },
  'stories short help' => {
    'lastUpdated' => '1252336265',
    'message' => 'Anzahl der angezeigten Berichte pro Seite'
  },
  'story template' => {
    'lastUpdated' => '1252336274',
    'message' => 'Berichtstemplate'
  },
  'story template help' => {
    'lastUpdated' => '1252336318',
    'message' => 'Template zur Anzeige von Berichtsassets zu diesem Berichtsthema'
  },
  'story_loop' => {
    'lastUpdated' => '1295596997',
    'message' => 'Eine Schleife die die letzten Berichte zu diesem Thema enthält. Zusätzlich zu den aufgeführten Variablen sind alle View-Template-Variablen des Story-Assets nutzbar.'
  },
  'storytopic asset template variables title' => {
    'lastUpdated' => '1252336355',
    'message' => 'Story Topic Asset Template Variables'
  },
  'template' => {
    'lastUpdated' => '1252336365',
    'message' => 'Haupttemplate'
  },
  'template help' => {
    'lastUpdated' => '1252336416',
    'message' => 'Template zur Anzeige des Berichtsthemas'
  },
  'title' => {
    'lastUpdated' => '1252336394',
    'message' => 'Titel des Berichts'
  },
  'topStory' => {
    'lastUpdated' => '1296988385',
    'message' => 'Variable die gleichartige Werte wie story_loop enthält  aber für topStory. Verwendung z.B. mit topStory.hasPhoto usw.'
  },
  'topStoryCreationDate' => {
    'lastUpdated' => '1252336445',
    'message' => 'Datum als Epochangabe, an dem der Bericht erstellt oder ins Berichtarchiv augenommen wurde.'
  },
  'topStoryImageAlt' => {
    'lastUpdated' => '1252336520',
    'message' => 'Alternativer Bildtext des ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageByline' => {
    'lastUpdated' => '1252336532',
    'message' => 'Unterschrift des des ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageCaption' => {
    'lastUpdated' => '1252336547',
    'message' => 'Bildüberschrift des ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageLink' => {
    'lastUpdated' => '1252336563',
    'message' => 'Link zum ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageTitle' => {
    'lastUpdated' => '1252336578',
    'message' => 'Bildtitel des ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStoryImageUrl' => {
    'lastUpdated' => '1252336590',
    'message' => 'URL zum ersten Photos des Top-Berichts, falls vorhanden.'
  },
  'topStorySubtitle' => {
    'lastUpdated' => '1252336603',
    'message' => 'Untertitel des Top-Berichtes'
  },
  'topStoryTitle' => {
    'lastUpdated' => '1252336612',
    'message' => 'Titel des Topberichtes'
  },
  'topStoryUrl' => {
    'lastUpdated' => '1252336631',
    'message' => 'URL um den Topbericht anzuzeigen'
  },
  'url' => {
    'lastUpdated' => '1252336647',
    'message' => 'URL um einen Bericht anzuzeigen'
  },
  'view template' => {
    'lastUpdated' => '1252336654',
    'message' => 'View Story Topic Template'
  }
}
;

1;
